@@ -586,13 +586,28 @@ if(type%in%c("Triang","STriang"))
 #   invisible()
 #}
 
-"pim.header"<- function(group,param.name,parameters,ncol,stratum,tostratum,strata.labels,mixtures,session=NULL,socc=NULL)
+"pim.header"<- function(group,param.name,parameters,ncol,stratum,tostratum,strata.labels,mixtures,session=NULL,socc=NULL,bracket=FALSE)
 {
   if(!is.null(stratum)&length(strata.labels)>0)
-     if(!is.null(tostratum))
-        stratum.designation=paste(strata.labels[stratum],"to",strata.labels[tostratum])
-     else
-        stratum.designation= paste(strata.labels[stratum],":Stratum",stratum,sep="")
+  {
+	  if(bracket)stratum.designation=""	 
+	  if(!is.null(tostratum))
+	  {
+		  if(bracket)
+			  param.name=paste(param.name,"[",stratum,",",tostratum,"]",sep="")
+		  else
+			  stratum.designation=paste(stratum,"to",tostratum)
+#		  stratum.designation=paste(strata.labels[stratum],"to",strata.labels[tostratum])
+	  }
+	  else
+	  {
+		  if(bracket)
+			  param.name=paste(param.name,"[",stratum,"]",sep="")
+		  else
+			  stratum.designation= paste(stratum,":Stratum",stratum,sep="")
+#		  stratum.designation= paste(strata.labels[stratum],":Stratum",stratum,sep="")
+	  }
+  }
   else
      stratum.designation=""
   if(is.null(session))
@@ -702,13 +717,17 @@ else
 #  follows code in make.mark.model except it uses renumber.pims and print.pim
 #  to renumber and print out the pim structure.
 #
+if(model$data$model=="RDMSOccRepro")
+	bracket=TRUE
+else
+	bracket=FALSE
 for (i in 1:length(parameters)) {
      for (j in 1:length(model$pims[[i]]))
      {
          ncol = dim(model$pims[[i]][[j]]$pim)[2]
          string=pim.header(pim[[i]][[j]]$group,param.names[i],parameters[[i]],
                    ncol,model$pims[[i]][[j]]$stratum,model$pims[[i]][[j]]$tostratum,model$strata.labels,
-				   mixtures,model$pims[[i]][[j]]$session,parameters[[i]]$socc)
+				   mixtures,model$pims[[i]][[j]]$session,parameters[[i]]$socc,bracket=bracket)
          write(string, file = outfile, append = TRUE)
          if(parameters[[i]]$type %in% c("Triang","STriang"))
          {
@@ -906,11 +925,11 @@ create.pim=function(nocc,parameters,npar,mixtures)
         if(mixtures>1)
             if(!is.null(parameters$mix)&&parameters$mix)
                 nmix=mixtures+parameters$rows
-            for(k in 1:nmix)
-            {
-                mat=rbind(mat,npar:(npar+ncol-1))
-                npar=npar+ncol
-            }
+        for(k in 1:nmix)
+        {
+            mat=rbind(mat,npar:(npar+ncol-1))
+            npar=npar+ncol
+        }
    }
 return(mat)
 }
@@ -978,12 +997,19 @@ create.agenest.var=function(data,init.agevar,time.intervals)
   {
 #
 #     For parameters that can be possibly shared, see if they are not shared and if not then create
-#     default formula if one not specified
+#     default formula if one not specified; also use link from dominant parameter
 #
-	  if(!is.null(parameters[[i]]$share)&&!parameters[[i]]$share)
-      {
-		  shared_par=parameters[[i]]$pair
-	      if(is.null(parameters[[shared_par]]$formula))parameters[[shared_par]]$formula=~1
+	  if(!is.null(parameters[[i]]$share))
+	  {
+		  if(!parameters[[i]]$share)
+          {
+		      shared_par=parameters[[i]]$pair
+	          if(is.null(parameters[[shared_par]]$formula))parameters[[shared_par]]$formula=~1
+	      }else
+		  {
+			  shared_par=parameters[[i]]$pair
+			  parameters[[shared_par]]$link=parameters[[i]]$link	  
+		  }
 	  }
 #
 #     Test validity of link functions
@@ -1263,25 +1289,15 @@ create.agenest.var=function(data,init.agevar,time.intervals)
      k=0
      for(j in 1:number.of.groups)
      {
-	   sub.stratum=0
-	   if(!is.null(parameters[[i]]$sub.stratum))sub.stratum=parameters[[i]]$sub.stratum
-	   all.tostrata=FALSE
-	   if(sub.stratum==-1)
+	   if(is.null(parameters[[i]]$bystratum)||!parameters[[i]]$bystratum)
+         xstrata=1
+	   else
+		 xstrata=unique(ddl[[i]]$stratum)
+	   for (jj in xstrata)
 	   {
-		   all.tostrata=TRUE
-		   sub.stratum=0
-	   }
-       for (jj in 1:(nstrata-sub.stratum))
-       {
           other.strata=1
           if(!is.null(parameters[[i]]$tostrata))
-          {
-             nsubtract.stratum=match(parameters[[i]]$subtract.stratum,data$strata.labels)
-			 if(!all.tostrata)
-				 other.strata= sequence(nstrata)[sequence(nstrata)!=nsubtract.stratum[jj]]
-			 else
-				 other.strata= 1:nstrata		 
-          }
+			  other.strata=unique(ddl[[i]]$tostratum[ddl[[i]]$stratum==jj])
           for(to.stratum in other.strata)
           {
                if(model.list$robust && parameters[[i]]$secondary)
@@ -1298,8 +1314,12 @@ create.agenest.var=function(data,init.agevar,time.intervals)
                {
                   k=k+1
                   pim[[i]][[k]]=list()
+				  if(data$model=="RDMSOccRepro" & names(parameters)[i]=="Phi0")
+				  {
+					  pim[[i]][[k]]$pim=matrix(1:length(data$strata.labels),nrow=1)   
+				  } else	 
 				  if(!multi.session)
-						  pim[[i]][[k]]$pim=create.pim(nocc,parameters[[i]],npar,mixtures)
+					 pim[[i]][[k]]$pim=create.pim(nocc,parameters[[i]],npar,mixtures)
 				  else
                   {
                      if(is.na(parameters[[i]]$num))
@@ -1314,7 +1334,7 @@ create.agenest.var=function(data,init.agevar,time.intervals)
 					 pim[[i]][[k]]$session.label=levels(ddl[[i]]$session)[l]
                   }
                   pim[[i]][[k]]$group=j
-                  if(length(data$strata.labels)>0) pim[[i]][[k]]$stratum=jj
+                  if(length(data$strata.labels)>0 && !is.null(parameters[[i]]$bystratum) && parameters[[i]]$bystratum) pim[[i]][[k]]$stratum=jj
                   if(!is.null(parameters[[i]]$tostrata)) pim[[i]][[k]]$tostratum=to.stratum
                   npar=max(pim[[i]][[k]]$pim)+1
                }
@@ -1348,6 +1368,14 @@ create.agenest.var=function(data,init.agevar,time.intervals)
            fixlist=as.numeric(rn)
         }
      }
+#
+#    Add any values specified with fix column in ddl
+#
+	 if(!is.null(ddl[[parx]]$fix))
+	 {
+		 fixvalues=c(fixvalues,ddl[[parx]]$fix[!is.na(ddl[[parx]]$fix)])
+		 fixlist=c(fixlist,as.numeric(row.names(ddl[[parx]][!is.na(ddl[[parx]]$fix),])))
+	 }
      if(!is.null(parameters[[i]]$fixed)|!is.null(fixlist))
      {
 #
@@ -1419,6 +1447,15 @@ create.agenest.var=function(data,init.agevar,time.intervals)
                     stop()
                  }
              }
+			 # check for duplicates and use latter values
+             if(any(duplicated(fixlist)))
+			 {
+				 message(paste("\nSome indices for fixed parameters were duplicated for ",parx,"; using latter values\n"))
+				 uniqIndices=which(!duplicated(rev(fixlist)))
+				 fixlist=rev(fixlist)[uniqIndices]
+				 fixvalues=rev(fixvalues)[uniqIndices]
+			 }
+             # assign all.different indices by adding first pim index-1
              fixlist=fixlist+ pim[[i]][[1]]$pim[1,1]-1
              for(k in 1:length(fixlist))
              {
@@ -1597,13 +1634,15 @@ create.agenest.var=function(data,init.agevar,time.intervals)
 #
   complete.design.matrix=NULL
   nrows=0
+  lastpim=length( pim[[length(parameters)]])
+  lastindex=sum(sapply(full.ddl[1:length(parameters)],nrow))
+#  lastindex=max(pim[[length(parameters)]][[lastpim]]$pim)
   for(i in 1:length(parameters))
   {
+	 # parameters with NULL formula have been merged with a shared parameter
      if(!is.null(parameters[[i]]$formula))
      {    
         mat=NULL
-        lastpim=length( pim[[length(parameters)]])
-        lastindex=max(pim[[length(parameters)]][[lastpim]]$pim)
 		pair=parameters[[i]]$pair
 		if(!is.null(pair) && pair !="" && !is.null(parameters[[pair]]$share) && parameters[[pair]]$share)
 		{
@@ -1631,7 +1670,7 @@ create.agenest.var=function(data,init.agevar,time.intervals)
   complete.design.matrix=as.data.frame(complete.design.matrix)
 
 #
-#  If there any initial values, output them to the MARK input file
+#  If there are any initial values, output them to the MARK input file
 #  after making sure that the vector length matches the number of parameters  
 #
    if(!is.null(initial))
@@ -1721,7 +1760,7 @@ create.agenest.var=function(data,init.agevar,time.intervals)
               }
               else
               {
-                 if(parx=="pent")
+                 if(parx%in% c("pent","alpha"))
                  {
                      nsets=length(pim[[parx]])
                      for (kk in 1:nsets)
@@ -1793,7 +1832,7 @@ create.agenest.var=function(data,init.agevar,time.intervals)
       if(!is.null(full.ddl[[parx]]$cohort))strings=paste(strings," c",full.ddl[[parx]]$cohort,sep="")
 	  if(!is.null(full.ddl[[parx]]$occ.cohort))strings=paste(strings," c",full.ddl[[parx]]$occ.cohort,sep="")
 	  if(!is.null(full.ddl[[parx]]$age))strings=paste(strings," a",full.ddl[[parx]]$age,sep="")
-	  if(!is.null(full.ddl[[parx]]$occ))strings=paste(strings," o",full.ddl[[parx]]$occ,sep="")
+	  if("occ"%in%names(full.ddl[[parx]]))strings=paste(strings," o",full.ddl[[parx]]$occ,sep="")
 	  if(model.list$robust && parameters[[parx]]$secondary)
          strings=paste(strings," s",full.ddl[[parx]]$session,sep="")
       if(!is.null(full.ddl[[parx]]$time))strings=paste(strings," t",full.ddl[[parx]]$time,sep="")
@@ -1895,4 +1934,3 @@ create.agenest.var=function(data,init.agevar,time.intervals)
   class(model)=c("mark",data$model)
   return(model)
 }
-
