@@ -48,6 +48,7 @@
 #' @param external if TRUE the mark object is saved externally rather than in
 #' the workspace; the filename is kept in its place
 #' @param threads number of cpus to use with mark.exe if positive or number of cpus to remain idle if negative
+#' @param ignore.stderr If set TRUE, messages from mark.exe are suppressed; they are automatically suppressed with Rterm
 #' @return model: MARK model object with the base filename stored in
 #' \code{output} and the extracted \code{results} from the output file appended
 #' onto list; see \code{\link{mark}} for a detailed description of a
@@ -80,7 +81,7 @@
 #' }
 run.mark.model <-
 function(model,invisible=FALSE,adjust=TRUE,filename=NULL,prefix="mark",realvcv=FALSE,
-delete=FALSE,external=FALSE,threads=-1)
+delete=FALSE,external=FALSE,threads=-1,ignore.stderr=FALSE)
 {
 # -----------------------------------------------------------------------------------------------------------------------
 #
@@ -170,12 +171,12 @@ delete=FALSE,external=FALSE,threads=-1)
 								 " v=",vcvfile, " r=",resfile, " threads=", threads,sep = ""),ignore.stdout=TRUE,ignore.stderr=TRUE)
 			 else
 				 system(paste(markpath, " i=",inputfile," o=", outfile,
-								 " v=",vcvfile, " r=",resfile, " threads=", threads,sep = ""))
+								 " v=",vcvfile, " r=",resfile, " threads=", threads,sep = ""),ignore.stderr=ignore.stderr)
 			 
 		 }else
 		 {
 			 system(paste(markpath, " i=",inputfile," o=", outfile,
-								 " v=",vcvfile, " r=",resfile, " threads=", threads,sep = ""),invisible=TRUE)
+								 " v=",vcvfile, " r=",resfile, " threads=", threads,sep = ""),invisible=TRUE,ignore.stderr=ignore.stderr)
 			 if(file.exists("fort.0"))unlink("fort.0")
 		 }
   } else
@@ -184,7 +185,7 @@ delete=FALSE,external=FALSE,threads=-1)
     if(!exists("MarkPath"))MarkPath=""
     if(RunMark)
        system(paste("mark i=",inputfile," o=", outfile,
-            " v=", vcvfile," r=",resfile, " threads=", threads,sep = ""))
+            " v=", vcvfile," r=",resfile, " threads=", threads,sep = ""),ignore.stderr=ignore.stderr)
   }
 #
 # Read in the output file
